@@ -33,14 +33,14 @@ int32_t SPVM__Sys__IO__FileStream__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
       if (is_pipe) {
         int32_t status = pclose(fh);
         if (status == -1) {
-          env->die(env, stack, "[System Error]pclose() failed:%s.", env->strerror_nolen(env, stack, errno), __func__, FILE_NAME, __LINE__);
+          env->die(env, stack, "[System Error]pclose() failed(%d: %s).", errno, env->strerror_nolen(env, stack, errno), __func__, FILE_NAME, __LINE__);
           return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
         }
       }
       else {
         int32_t status = fclose(fh);
         if (status == EOF) {
-          env->die(env, stack, "[System Error]fclose() failed:%s.", env->strerror_nolen(env, stack, errno), __func__, FILE_NAME, __LINE__);
+          env->die(env, stack, "[System Error]fclose() failed(%d: %s).", errno, env->strerror_nolen(env, stack, errno), __func__, FILE_NAME, __LINE__);
           return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
         }
       }
