@@ -9,14 +9,18 @@
 static const char* FILE_NAME = "Sys/Time/Timeval.c";
 
 int32_t SPVM__Sys__Time__Timeval__new(SPVM_ENV* env, SPVM_VALUE* stack) {
-
+  
   int32_t error_id = 0;
   
-  struct timeval* st_tv = env->new_memory_block(env, stack, sizeof(struct timeval));
+  struct timeval* tv = env->new_memory_block(env, stack, sizeof(struct timeval));
   
-  void* obj_tv = env->new_pointer_object_by_name(env, stack, "Sys::Time::Timeval", st_tv, &error_id, __func__, FILE_NAME, __LINE__);
+  tv->tv_sec = stack[0].lval;
+  
+  tv->tv_usec = stack[1].lval;
+  
+  void* obj_tv = env->new_pointer_object_by_name(env, stack, "Sys::Time::Timeval", tv, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
-
+  
   stack[0].oval = obj_tv;
   
   return 0;
@@ -26,11 +30,11 @@ int32_t SPVM__Sys__Time__Timeval__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_tv = stack[0].oval;
   
-  struct timeval* st_tv = env->get_pointer(env, stack, obj_tv);
+  struct timeval* tv = env->get_pointer(env, stack, obj_tv);
   
-  assert(st_tv);
+  assert(tv);
   
-  env->free_memory_block(env, stack, st_tv);
+  env->free_memory_block(env, stack, tv);
   
   return 0;
 }
@@ -39,9 +43,9 @@ int32_t SPVM__Sys__Time__Timeval__tv_sec(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_tv = stack[0].oval;
   
-  struct timeval* st_tv = env->get_pointer(env, stack, obj_tv);
+  struct timeval* tv = env->get_pointer(env, stack, obj_tv);
   
-  stack[0].lval = st_tv->tv_sec;
+  stack[0].lval = tv->tv_sec;
   
   return 0;
 }
@@ -52,9 +56,9 @@ int32_t SPVM__Sys__Time__Timeval__set_tv_sec(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int64_t tv_sec = stack[1].lval;
   
-  struct timeval* st_tv = env->get_pointer(env, stack, obj_tv);
+  struct timeval* tv = env->get_pointer(env, stack, obj_tv);
   
-  st_tv->tv_sec = tv_sec;
+  tv->tv_sec = tv_sec;
   
   return 0;
 }
@@ -63,9 +67,9 @@ int32_t SPVM__Sys__Time__Timeval__tv_usec(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_tv = stack[0].oval;
   
-  struct timeval* st_tv = env->get_pointer(env, stack, obj_tv);
+  struct timeval* tv = env->get_pointer(env, stack, obj_tv);
   
-  stack[0].lval = st_tv->tv_usec;
+  stack[0].lval = tv->tv_usec;
   
   return 0;
 }
@@ -76,9 +80,9 @@ int32_t SPVM__Sys__Time__Timeval__set_tv_usec(SPVM_ENV* env, SPVM_VALUE* stack)
   
   int64_t tv_usec = stack[1].lval;
   
-  struct timeval* st_tv = env->get_pointer(env, stack, obj_tv);
+  struct timeval* tv = env->get_pointer(env, stack, obj_tv);
   
-  st_tv->tv_usec = tv_usec;
+  tv->tv_usec = tv_usec;
   
   return 0;
 }
